@@ -32,9 +32,9 @@
 #include <resParser.h>
 
 #include <kdeSupport.h>
-#include <QtGui/QPixmap>
-#include <QtCore/QTextStream>
-#include <QtGui/QVBoxLayout>
+#include <QPixmap>
+#include <QTextStream>
+#include <QVBoxLayout>
 
 namespace XX_NAMESPACE_PREFIX { namespace Manual {
 #if !defined(WINDOWS)
@@ -44,15 +44,15 @@ char text[]="<h1>xxdiff documentation</h1><p>Not available under Windows.</p>";
 #endif
 }}
 
-#include <QtGui/QDialog>
-#include <QtGui/QMessageBox>
-#include <QtGui/QLayout>
-#include <QtGui/QLabel>
-#include <QtGui/QPushButton>
-#include <QtGui/QPalette>
-#include <QtGui/QTextBrowser>
-#include <QtCore/QByteArray>
-#include <QtGui/QLineEdit>
+#include <QDialog>
+#include <QMessageBox>
+#include <QLayout>
+#include <QLabel>
+#include <QPushButton>
+#include <QPalette>
+#include <QTextBrowser>
+#include <QByteArray>
+#include <QLineEdit>
 
 #include <iostream>
 #include <stdio.h>
